==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/head.php <==
<?php

switch ($messaggio) {

case "MENU":  				$messaggio = "MENY"; break;
case "PRENOTAZIONE":  			$messaggio = "BOKNING"; break;
case "TABELLE":  			$messaggio = "TABELLER"; break;
case "GENNAIO":  			$messaggio = "JANUARI"; break;
case "FEBBRAIO":  			$messaggio = "FEBRUARI"; break;
case "MARZO":  				$messaggio = "MARS"; break;
case "MAGGIO":  			$messaggio = "MAJ"; break;
case "GIUGNO":  			$messaggio = "JUNI"; break;
case "LUGLIO":  			$messaggio = "JULI"; break;
case "AGOSTO":  			$messaggio = "AUGUSTI"; break;
case "OTTOBRE":  			$messaggio = "OKTOBER"; break;
case "PRENOTAZIONI":  			$messaggio = "BOKNINGAR"; break;
case "SPESE":  				$messaggio = "BETALNINGAR"; break;
case "TARIFFE":  			$messaggio = "PRISER"; break;
case "CLIENTI":  			$messaggio = "KUNDER"; break;
case "INSERIRE":  			$messaggio = "INFOGA"; break;
case "CLIENTE":  			$messaggio = "KUND"; break;
case "PREZZI":  			$messaggio = "PRISER"; break;
case "REGOLE":  			$messaggio = "REGLER"; break;
case "CONFIGURA":  			$messaggio = "ANPASSA"; break;
case "TUTTE":  				$messaggio = "ALLA"; break;
case "CORRENTI":  			$messaggio = "NUVARANDE"; break;
case "FUTURE":  			$messaggio = "FRAMTIDA"; break;
case "ARRIVI":  			$messaggio = "ANKOMSTER"; break;
case "PARTENZE":  			$messaggio = "AVRESOR"; break;
case "MESSAGGI":  			$messaggio = "MEDDELANDEN"; break;
case "ENTRATE&nbsp;PREN.":  		$messaggio = "RES.&nbsp;BETALNINGAR"; break;
case "UTENTI":  			$messaggio = "ANV&Auml;NDARE"; break;
case "INTERCONN.":  			$messaggio = "MELLANKOPPL."; break;
case "STATISTICHE":  			$messaggio = "STATISTIK"; break;
case "INVENTARIO":  			$messaggio = "INVENTORIUM"; break;
case "CERCA":  				$messaggio = "S&Ouml;K"; break;
case "VAI":  				$messaggio = "GO"; break;
case "APRILE":  			$messaggio = "APRIL"; break;
case "SETTEMBRE":  			$messaggio = "SEPTEMBER"; break;
case "NOVEMBRE":  			$messaggio = "NOVEMBER"; break;
case "DICEMBRE":  			$messaggio = "DECEMBER"; break;
case "CASSE":  				$messaggio = "CASHBOXES"; break;
case "SITO WEB":  			$messaggio = "WEBSITE"; break;
case "BACKUP":  			$messaggio = "BACKUP"; break;
case "DOCUMENTI":  			$messaggio = "DOCUMENTS"; break;
case "P.TO&nbsp;VENDITA":  		$messaggio = "POINT&nbsp;OF&nbsp;SALE"; break;
case "NUMERO":  			$messaggio = "NUMBER"; break;
case "COSTI AGGIUNTIVI":  		$messaggio = "EXTRA COSTS"; break;
case "CAPARRE E TASSE":  		$messaggio = "DEPOSITS AND TAXES"; break;
case "PARTENZE E CORRENTI":  		$messaggio = "DEPART. AND CURRENT"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/head.php <==
<?php

switch ($messaggio) {

case "MENU":  				$messaggio = "MENY"; break;
case "PRENOTAZIONE":  			$messaggio = "BOKNING"; break;
case "TABELLE":  			$messaggio = "TABELLER"; break;
case "GENNAIO":  			$messaggio = "JANUARI"; break;
case "FEBBRAIO":  			$messaggio = "FEBRUARI"; break;
case "MARZO":  				$messaggio = "MARS"; break;
case "MAGGIO":  			$messaggio = "MAJ"; break;
case "GIUGNO":  			$messaggio = "JUNI"; break;
case "LUGLIO":  			$messaggio = "JULI"; break;
case "AGOSTO":  			$messaggio = "AUGUSTI"; break;
case "OTTOBRE":  			$messaggio = "OKTOBER"; break;
case "PRENOTAZIONI":  			$messaggio = "BOKNINGAR"; break;
case "SPESE":  				$messaggio = "BETALNINGAR"; break;
case "TARIFFE":  			$messaggio = "PRISER"; break;
case "CLIENTI":  			$messaggio = "KUNDER"; break;
case "INSERIRE":  			$messaggio = "INFOGA"; break;
case "CLIENTE":  			$messaggio = "KUND"; break;
case "PREZZI":  			$messaggio = "PRISER"; break;
case "REGOLE":  			$messaggio = "REGLER"; break;
case "CONFIGURA":  			$messaggio = "ANPASSA"; break;
case "TUTTE":  				$messaggio = "ALLA"; break;
case "CORRENTI":  			$messaggio = "NUVARANDE"; break;
case "FUTURE":  			$messaggio = "FRAMTIDA"; break;
case "ARRIVI":  			$messaggio = "ANKOMSTER"; break;
case "PARTENZE":  			$messaggio = "AVRESOR"; break;
case "MESSAGGI":  			$messaggio = "MEDDELANDEN"; break;
case "ENTRATE&nbsp;PREN.":  		$messaggio = "RES.&nbsp;BETALNINGAR"; break;
case "UTENTI":  			$messaggio = "ANV&Auml;NDARE"; break;
case "INTERCONN.":  			$messaggio = "MELLANKOPPL."; break;
case "STATISTICHE":  			$messaggio = "STATISTIK"; break;
case "INVENTARIO":  			$messaggio = "INVENTORIUM"; break;
case "CERCA":  				$messaggio = "S&Ouml;K"; break;
case "VAI":  				$messaggio = "GO"; break;
case "APRILE":  			$messaggio = "APRIL"; break;
case "SETTEMBRE":  			$messaggio = "SEPTEMBER"; break;
case "NOVEMBRE":  			$messaggio = "NOVEMBER"; break;
case "DICEMBRE":  			$messaggio = "DECEMBER"; break;
case "CASSE":  				$messaggio = "CASHBOXES"; break;
case "SITO WEB":  			$messaggio = "WEBSITE"; break;
case "BACKUP":  			$messaggio = "BACKUP"; break;
case "DOCUMENTI":  			$messaggio = "DOCUMENTS"; break;
case "P.TO&nbsp;VENDITA":  		$messaggio = "POINT&nbsp;OF&nbsp;SALE"; break;
case "NUMERO":  			$messaggio = "NUMBER"; break;
case "COSTI AGGIUNTIVI":  		$messaggio = "EXTRA COSTS"; break;
case "CAPARRE E TASSE":  		$messaggio = "DEPOSITS AND TAXES"; break;
case "PARTENZE E CORRENTI":  		$messaggio = "DEPART. AND CURRENT"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# Simple theme top menu drop-down menus widths (leave defaults if widths are OK)

case "insert-ddw":  			$messaggio = "100px"; break;
case "tables-ddw":  			$messaggio = "100px"; break;
case "months-ddw":  			$messaggio = "86px"; break;
case "reservations-ddw":  		$messaggio = "150px"; break;
case "clients-ddw":  			$messaggio = "15em"; break;
case "rates-ddw":  			$messaggio = "150px"; break;
case "configure-ddw":  			$messaggio = "86px"; break;
} # fine switch ($messaggio)

?>
